#
# spec file for package libvorbis (Version 1.2.0)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           libvorbis
BuildRequires:  libogg-devel pkgconfig
Summary:        The Vorbis General Audio Compression Codec
Version:        1.2.0
Release:        83.3.1
Group:          System/Libraries
License:        BSD3c(or similar)
Url:            http://www.vorbis.com/
# bug437293
%ifarch ppc64
Obsoletes:      libvorbis-64bit
%endif
#
Source:         %{name}-%{version}.tar.bz2
Patch1:         libvorbis-lib64.dif
Patch2:         libvorbis-m4.dif
# URL http://www.geocities.jp/aoyoume/aotuv/
Patch5:         libvorbis-%{version}-aotuv-b5.7.diff
# included in aotuv-b5.7.diff
# Patch6:         libvorbis-%{version}-warning-fixes.diff
Patch7:         libvorbis-cflags.diff
Patch9:         libvorbis-doc-fixes.diff
Patch10:        libvorbis-pkgconfig.patch
# These security fixes are already included aotuv-b5.7 patch
# Patch11:        libvorbis-r14598-r14600-CVE-2008-1420.diff
# Patch12:        libvorbis-r14602-CVE-2008-1419.diff
# Patch13:        libvorbis-r14604-CVE-2008-1423.diff
Patch14:        libvorbis-am111.diff
# bnc608192: r16217 is already in aotuv-b5.7 patch
Patch15:        libvorbis-r16218-CVE-2009-2663.diff
Patch16:        libvorbis-r16222-CVE-2009-2663.diff
Patch17:        libvorbis-r16326-CVE-2009-3379.diff
Patch18:        libvorbis-r16597-CVE-2009-3379.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Vorbis is a fully open, nonproprietary, patent-and-royalty-free, and
general-purpose compressed audio format for audio and music at fixed
and variable bit rates from 16 to 128 kbps/channel.

The native bitstream format of Vorbis is libogg (Ogg). Alternatively,
libmatroska (matroska) can also be used.



Authors:
--------
    Monty <monty@xiph.org>
    Xiphophorus Company <team@xiph.org>

%package devel
License:        BSD3c(or similar)
Summary:        Include Files and Libraries mandatory for Ogg Vorbis Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel, libogg-devel
Requires:       %{name} = %{version}
# bug437293
%ifarch ppc64
Obsoletes:      libvorbis-devel-64bit
%endif
#

%description devel
This package contains all necessary include files and libraries needed
to compile and develop applications that use libvorbis.



Authors:
--------
    Monty <monty@xiph.org>
    Xiphophorus Company <team@xiph.org>

%package doc
License:        BSD3c(or similar)
Summary:        Documentation of Ogg/Vorbis library
Group:          Documentation/Other

%description doc
This package contains documents for Ogg/Vorbis library, including the
API reference.



Authors:
--------
    Monty <monty@xiph.org>
    Xiphophorus Company <team@xiph.org>

%prep
%setup -q
%patch2
%patch5 -p1
# %patch6
%patch7
%patch9
%patch10
# %patch11 -p3
# %patch12 -p3
# %patch13 -p3
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
if [ "%_lib" == "lib64" ]; then
%patch1
fi

%build
autoreconf -fi
%configure \
	--with-ogg-libraries=%{_libdir} \
	--disable-static
make

%install
%makeinstall
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
mv $RPM_BUILD_ROOT%{_datadir}/doc/libvorbis-* $RPM_BUILD_ROOT%{_docdir}/%{name}/html
install -c -m 0644 doc/Vorbis_I_spec.* $RPM_BUILD_ROOT%{_docdir}/%{name}/html
ln -s white-xifish.png $RPM_BUILD_ROOT%{_docdir}/%{name}/html/fish_xiph_org.png
cp COPYING AUTHORS README $RPM_BUILD_ROOT%{_docdir}/%{name}
cp *.txt $RPM_BUILD_ROOT%{_docdir}/%{name}
# remove unneeded files
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root)
%{_datadir}/aclocal/*.m4
%{_includedir}/vorbis
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%defattr(-,root,root)
%doc %{_docdir}/%{name}

%changelog
* Wed May 26 2010 tiwai@suse.de
- VUL-0: ibvorbis: memory corruption while parsing ogg files
  (bnc#608192, CVE-2009-2663, CVE-2009-3379)
* Thu Jul 23 2009 tiwai@suse.de
- updated to aoTuV patch version beta5.7:
  * including security fixes
  * improved encoding speed of low bitrate mode
  * reduced distrotion by clipping at low sampling frequency
  * fixed noise control part of impulse block
  * tuning of each part was redone
  * expanded noise control of the impulse block
  * fixed pre-echo reduction code
  * noise normalization reviewed
  * detailed tuning done again
* Mon Jun 22 2009 coolo@novell.com
- fix build with automake 1.11
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Nov 20 2008 pth@suse.de
- Fix the test in libvorbis-m4.dif and adapt libvorbis-lib64.dif.
* Wed May 14 2008 tiwai@suse.de
- VUL-0: Multiple vulnerabilities in libogg and libvorbis
  (bnc#372246)
  * CVE-2008-1419 vorbis: zero-dim codebooks can cause crash,
    infinite loop or heap overflow
  * CVE-2008-1420 vorbis: integer overflow in partvals computation
  * CVE-2008-1423 vorbis: integer oveflow caused by huge codebooks
* Mon Apr 28 2008 tiwai@suse.de
- fixed dependency in *.pc files (bnc#384153)
- removed old run_ldconfig
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Aug  2 2007 tiwai@suse.de
- updated to version 1.2.0:
  * new ov_fopen() convenience call that avoids the common
  stdio conflicts with ov_open() and MSVC runtimes.
  * libvorbisfile now handles multiplexed streams
  * improve robustness to corrupt input streams
  * fix a minor encoder bug
  * updated RTP draft
  * build system updates
  * minor corrections to the specification
* Fri Jul 27 2007 tiwai@suse.de
- fix the documentation link (#293784)
- split documentation to doc subpackage
- remove -fno-strict-aliasing gcc option
* Mon Jul  9 2007 tiwai@suse.de
- fix array boundary conditional flaw in mapping (#287124,
  CVE-2007-3106)
* Mon Apr 23 2007 tiwai@suse.de
- use aoTuV beta5 patch:
  * The action of noise normalization has been improved.
  * The threshold of a stereo mode change was calculated
    dynamically.
  * Noise control of an impulse block was changed (quality 0-10
    / 32-48kHz). And pre-echo decreased slightly.
  * Tuning of each part was redone according to above-mentioned
    changed part and additional part.
* Mon Apr 16 2007 tiwai@suse.de
- follow library packaging policy
  * move docs to devel package
  * remove static library
- remove obsolete m4 files
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 tiwai@suse.de
- compile with -fstack-protector.
* Fri Dec  2 2005 tiwai@suse.de
- updated to version 1.1.2.
* Tue Oct 18 2005 tiwai@suse.de
- updated to version 1.1.1.
* Sun Sep  4 2005 aj@suse.de
- Build with -fno-strict-aliasing (#115135).
* Thu Jul  7 2005 tiwai@suse.de
- remove -fsigned-char (#93878).
- fixed Requires of devel subpackage.
* Mon Jun 20 2005 tiwai@suse.de
- updated to aoTuV beta4.
* Wed Jan 19 2005 tiwai@suse.de
- fixed compile warnings with gcc-4.0.
* Wed Nov 24 2004 tiwai@suse.de
- updated to libvorbis version 1.1.0.
- updated to aoTuV beta3.
* Thu Aug  5 2004 tiwai@suse.de
- applied aoTuV patch to improve the encoding quality.
* Fri Apr 16 2004 tiwai@suse.de
- fixed the type-punning.
- disabled the removal of $RPM_BUILD_ROOT in %%install.
* Wed Jan 21 2004 tiwai@suse.de
- fixed quoting in m4 files.
* Fri Jan  9 2004 adrian@suse.de
- add %%run_ldconfig to %%postun
* Fri Jan  9 2004 tiwai@suse.de
- updated to version 1.0.1.
  removed obsolete patches.
- added pkgconfig to neededforbuild.
* Sat Mar  1 2003 adrian@suse.de
- let libvorbis-devel require libogg-devel
* Fri Jan 17 2003 tiwai@suse.de
- fixed m4 macro (bug #21267).
* Thu Jan  9 2003 kukuk@suse.de
- Add *.la files to -devel filelist
* Wed Dec  4 2002 tiwai@suse.de
- fixed the undefined weak links.
- renamed m4.dif and lib64.dif with libvorbis- prefix to avoid
  filename conflictions.
* Thu Sep 19 2002 tiwai@suse.de
- don't add -I/usr/include to VORBIS_VFLAGS.
- fix test for prefix.
- move devel documents under %%{_docdir}/libvorbis-devel.
* Mon Aug 12 2002 tiwai@suse.de
- added Requires %%{name} = %%{version} to devel package.
* Tue Jul 23 2002 tiwai@suse.de
- fixed m4 file for lib64.
- provides the backward compatible m4 file.
* Mon Jul 22 2002 tiwai@suse.de
- updated to version 1.0.
- clean up the spec file.
- added %%run_ldconfig.
* Wed Jun 12 2002 meissner@suse.de
- rm acinclude.m4 so we don't have the problematic ogg.m4 (which contains
  /lib hardcoded).
* Thu Apr 18 2002 kukuk@suse.de
- Remove additional optimization, default is better
- Add --libdir to configure to build on x86_64
* Thu Feb  7 2002 tiwai@suse.de
- fixed build on s390x.
* Fri Jan  4 2002 tiwai@suse.de
- updated to RC3.
  sync with cvs 2002.01.04.
* Tue Dec  4 2001 tiwai@suse.de
- sync with cvs 2001.12.04.
* Wed Oct 24 2001 tiwai@suse.de
- sync with cvs 20011024.
  + fixed/updated documents
  + tuned up parameters
  + bugfixes on 64bit arch.
- removed Requires to libogg.
* Sat Oct 20 2001 schwab@suse.de
- Fix use of qsort.
* Mon Aug 13 2001 tiwai@suse.de
- updated to 1.0rc2 from cvs 20010813.
* Thu Jun  7 2001 tiwai@suse.de
- fixed build with the recent libtool.
* Tue Apr  3 2001 bk@suse.de
- make use of RPM_OPT_FLAGS
- include the include/vorbis dir into the file list(+rpm-macroized)
* Mon Mar 12 2001 tiwai@suse.de
- corrected copyright in spec file.
* Mon Feb 26 2001 tiwai@suse.de
- Updated to 1.0beta4.
* Wed Jan 31 2001 tiwai@suse.de
- Initial version: 1.0beta3.
